@@ -16,8 +16,8 @@
 #include "k3baudioencoder.h"
 #include "k3b_i18n.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QFile>
+#include <QDebug>
+#include <QFile>
 
 
 class K3b::AudioEncoder::Private
